@@ -5,43 +5,49 @@ import com.badlogic.gdx.scenes.scene2d.Actor
 import com.badlogic.gdx.scenes.scene2d.ui.Table
 import com.badlogic.gdx.utils.Align
 import com.unciv.Constants
-import com.unciv.ui.components.widgets.ExpanderTab
-import com.unciv.ui.components.extensions.addBorder
+import com.unciv.ui.components.UncivTooltip.Companion.addTooltip
 import com.unciv.ui.components.extensions.addSeparatorVertical
 import com.unciv.ui.components.extensions.darken
 import com.unciv.ui.components.extensions.surroundWithCircle
-import com.unciv.ui.components.extensions.toGroup
 import com.unciv.ui.components.extensions.toLabel
+import com.unciv.ui.components.extensions.toTextButton
 import com.unciv.ui.components.input.KeyboardBinding
+import com.unciv.ui.components.input.onActivation
 import com.unciv.ui.components.input.onClick
+import com.unciv.ui.components.widgets.ExpanderTab
 import com.unciv.ui.images.ImageGetter
+import com.unciv.ui.popups.AnimatedMenuPopup
 import com.unciv.ui.screens.basescreen.BaseScreen
 
 class SpecialistAllocationTable(private val cityScreen: CityScreen) : Table(BaseScreen.skin) {
     val city = cityScreen.city
+    private val smallButtonStyle = AnimatedMenuPopup.SmallButtonStyle()
 
     fun update() {
+        // 5 columns: "-" unassignButton, AllocationTable, "+" assignButton, SeparatorVertical, SpecialistsStatsTabe
         clear()
+
         // Auto/Manual Specialists Toggle
-        // Color of "color" coming from Skin.json that's loaded into BaseScreen
-        // 5 columns: unassignButton, AllocationTable, assignButton, SeparatorVertical, SpecialistsStatsTabe
         if (cityScreen.canCityBeChanged()) {
-            if (city.manualSpecialists) {
-                val manualSpecialists = "Manual Specialists".toLabel()
-                    .addBorder(5f, BaseScreen.skin.getColor("color"))
-                manualSpecialists.onClick {
-                    city.manualSpecialists = false
-                    city.reassignPopulation(); cityScreen.update()
-                }
-                add(manualSpecialists).colspan(5).row()
+            val toggleButton = if (city.manualSpecialists) {
+                "Manual Specialists".toTextButton(smallButtonStyle)
+                   .onActivation {
+                       city.manualSpecialists = false
+                       city.reassignPopulation()
+                       cityScreen.update()
+                   }
             } else {
-                val autoSpecialists = "Auto Specialists".toLabel()
-                    .addBorder(5f, BaseScreen.skin.getColor("color"))
-                autoSpecialists.onClick { city.manualSpecialists = true; update() }
-                add(autoSpecialists).colspan(5).row()
+                "Auto Specialists".toTextButton(smallButtonStyle)
+                    .onActivation {
+                        city.manualSpecialists = true
+                        update()
+                    }
             }
+            add(toggleButton).colspan(5).row()
         }
-        for ((specialistName, maxSpecialists) in city.population.getMaxSpecialists()) {
+
+        // Since getMaxSpecialists is a Counter, iteration is potentially in random order. Ensure consistency by simplified sorting (no collator)
+        for ((specialistName, maxSpecialists) in city.population.getMaxSpecialists().asSequence().sortedBy { it.key }) {
             if (!city.getRuleset().specialists.containsKey(specialistName)) // specialist doesn't exist in this ruleset, probably a mod
                 continue
             val newSpecialists = city.population.getNewSpecialists()
@@ -50,15 +56,16 @@ class SpecialistAllocationTable(private val cityScreen: CityScreen) : Table(Base
             if (cityScreen.canChangeState) add(getUnassignButton(assignedSpecialists, specialistName))
             add(getAllocationTable(assignedSpecialists, maxSpecialists, specialistName)).pad(10f)
             if (cityScreen.canChangeState) add(getAssignButton(assignedSpecialists, maxSpecialists, specialistName))
+
             addSeparatorVertical().pad(10f)
             add(getSpecialistStatsTable(specialistName)).row()
         }
+
         pack()
     }
 
 
     private fun getAllocationTable(assignedSpecialists: Int, maxSpecialists: Int, specialistName: String): Table {
-
         val specialistIconTable = Table()
         val specialistObject = city.getRuleset().specialists[specialistName]!!
         for (i in 1..maxSpecialists) {
@@ -68,6 +75,7 @@ class SpecialistAllocationTable(private val cityScreen: CityScreen) : Table(Base
             specialistIconTable.add(icon).size(30f)
             if (i % 5 == 0) specialistIconTable.row()
         }
+        specialistIconTable.addTooltip(specialistName, 24f)
         return specialistIconTable
     }
 
@@ -108,28 +116,33 @@ class SpecialistAllocationTable(private val cityScreen: CityScreen) : Table(Base
     private fun getSpecialistStatsTable(specialistName: String): Table {
         val specialistStatTable = Table().apply { defaults().padBottom(5f).padTop(5f) }
         val specialistStats = city.cityStats.getStatsOfSpecialist(specialistName)
+        val specialist = city.getRuleset().specialists[specialistName]!!
+        val maxStat = specialistStats.maxOf { it.value }
+        val lightGreen = Color(0x7fff7fff)
         var itemsInRow = 0
-        fun incrementItemsInRow(){
+
+        fun addWrapping(value: Int, labelColor: Color, icon: Actor) {
+            specialistStatTable.add(value.toString().toLabel(labelColor))
+            specialistStatTable.add(icon).size(20f).padRight(10f)
+
             itemsInRow++
-            if (itemsInRow % 3 == 0){
+            if (itemsInRow % 3 == 0) {
                 itemsInRow = 0
                 specialistStatTable.row()
             }
         }
 
-        for ((key, value) in specialistStats) {
-            if (value == 0f) continue
-            specialistStatTable.add(value.toInt().toLabel())
-            specialistStatTable.add(ImageGetter.getStatIcon(key.name)).size(20f).padRight(10f)
-            incrementItemsInRow()
+        // Show gpp points first, makes recognizing what the specialist is good for easier
+        // greatPersonPoints is a Counter so iteration order is potentially random:
+        // Sort by unit name without collator to ensure consistency in those rare mods where one Specialist gives points to several GP counters
+        for ((gpName, gpPoints) in specialist.greatPersonPoints.asSequence().sortedBy { it.key }) {
+            addWrapping(gpPoints, Color.GOLD, ImageGetter.getUnitIcon(gpName, Color.GOLD))
         }
 
-        val specialist = city.getRuleset().specialists[specialistName]!!
-
-        for (s in specialist.greatPersonPoints) {
-            specialistStatTable.add(s.value.toLabel())
-            specialistStatTable.add(ImageGetter.getUnitIcon(s.key, Color.GOLD).toGroup(20f)).padRight(10f)
-            incrementItemsInRow()
+        // This uses Stats.iterator() which ensures consistent Stat order and returns no zero value
+        // To make recognizing the Specialist still easier, the max values of the Stats are done in green
+        for ((stat, value) in specialistStats) {
+            addWrapping(value.toInt(), if (value == maxStat) lightGreen else Color.WHITE, ImageGetter.getStatIcon(stat.name))
         }
 
         return specialistStatTable
