@@ -8,13 +8,12 @@ import com.unciv.app.desktop.DesktopScreenMode.Companion.getMaximumWindowBounds
 import com.unciv.json.json
 import com.unciv.logic.files.SETTINGS_FILE_NAME
 import com.unciv.logic.files.UncivFiles
-import com.unciv.models.metadata.ScreenSize
-import com.unciv.models.metadata.WindowState
+import com.unciv.models.metadata.GameSettings.ScreenSize
+import com.unciv.models.metadata.GameSettings.WindowState
 import com.unciv.ui.components.fonts.Fonts
 import com.unciv.ui.screens.basescreen.BaseScreen
 import com.unciv.utils.Display
 import com.unciv.utils.Log
-import kotlin.math.max
 
 internal object DesktopLauncher {
 
@@ -49,27 +48,27 @@ internal object DesktopLauncher {
         config.setWindowIcon("ExtraImages/Icon.png")
         config.setTitle("Unciv")
         config.setHdpiMode(HdpiMode.Logical)
-        config.setWindowSizeLimits(120, 80, -1, -1)
+        config.setWindowSizeLimits(WindowState.minimumWidth, WindowState.minimumHeight, -1, -1)
 
         // We don't need the initial Audio created in Lwjgl3Application, HardenGdxAudio will replace it anyway.
         // Note that means config.setAudioConfig() would be ignored too, those would need to go into the HardenedGdxAudio constructor.
         config.disableAudio(true)
 
+        // LibGDX not yet configured, use regular java class
+        val maximumWindowBounds = getMaximumWindowBounds()
+
         val settings = UncivFiles.getSettingsForPlatformLaunchers()
         if (settings.isFreshlyCreated) {
             settings.screenSize = ScreenSize.Large // By default we guess that Desktops have larger screens
-            // LibGDX not yet configured, use regular java class
-            val maximumWindowBounds = getMaximumWindowBounds()
-            settings.windowState = WindowState(
-                width = maximumWindowBounds.width,
-                height = maximumWindowBounds.height
-            )
+            settings.windowState = WindowState(maximumWindowBounds)
             FileHandle(SETTINGS_FILE_NAME).writeString(json().toJson(settings), false, Charsets.UTF_8.name()) // so when we later open the game we get fullscreen
         }
         // Kludge! This is a workaround - the matching call in DesktopDisplay doesn't "take" quite permanently,
         // the window might revert to the "config" values when the user moves the window - worse if they
         // minimize/restore. And the config default is 640x480 unless we set something here.
-        config.setWindowedMode(max(settings.windowState.width, 100), max(settings.windowState.height, 100))
+        val (width, height) = settings.windowState.coerceIn(maximumWindowBounds)
+        config.setWindowedMode(width, height)
+
         config.setInitialBackgroundColor(BaseScreen.clearColor)
 
         if (!isRunFromJAR) {
